==> cxf-testutils-2.0.6.16-fuse-sources.jar: org/apache/type_test/doc/TestComplexRestriction3.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.ComplexRestriction3;


/**
 * <p>Java class for testComplexRestriction3 element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testComplexRestriction3">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}ComplexRestriction3"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}ComplexRestriction3"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testComplexRestriction3")
public class TestComplexRestriction3 {

    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected ComplexRestriction3 x;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected ComplexRestriction3 y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ComplexRestriction3 }
     *     
     */
    public ComplexRestriction3 getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ComplexRestriction3 }
     *     
     */
    public void setX(ComplexRestriction3 value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ComplexRestriction3 }
     *     
     */
    public ComplexRestriction3 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ComplexRestriction3 }
     *     
     */
    public void setY(ComplexRestriction3 value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.20-fuse-sources.jar: org/apache/type_test/doc/TestComplexRestriction3.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.ComplexRestriction3;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}ComplexRestriction3"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}ComplexRestriction3"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testComplexRestriction3")
public class TestComplexRestriction3 {

    @XmlElement(required = true)
    protected ComplexRestriction3 x;
    @XmlElement(required = true)
    protected ComplexRestriction3 y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ComplexRestriction3 }
     *     
     */
    public ComplexRestriction3 getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ComplexRestriction3 }
     *     
     */
    public void setX(ComplexRestriction3 value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ComplexRestriction3 }
     *     
     */
    public ComplexRestriction3 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ComplexRestriction3 }
     *     
     */
    public void setY(ComplexRestriction3 value) {
        this.y = value;
    }

}
